pub fn is_hypervisor_present() -> bool
Check if there is a hypervisor present Determine whether a suitable hypervisor is available to run this sandbox.
Returns a boolean indicating whether a suitable hypervisor is present.