FileSystemEmbedded

Struct FileSystemEmbedded 

pub struct FileSystemEmbedded { /* private fields */ }
Module resolution and loading functionality. File system implementation that uses embedded modules compiled into the binary.

This implementation stores all module contents in a compile-time perfect hash map, eliminating any runtime file system access. This is the basic secure option for module loading as it provides a completely closed set of available modules without filesystem access.

Example

use hyperlight_js::embed_modules;

let fs = embed_modules! {
    "math.js" => "../tests/fixtures/math.js",
    "strings.js" => "../tests/fixtures/strings.js",
};

Implementations

Source

impl FileSystemEmbedded

pub const fn new(modules: &'static Map<&'static str, &'static str>) -> Self

Create a new embedded file system with the given module map.

See the embed_modules! macro for an easier way to create