pub struct SandboxConfiguration { /* private fields */ }Expand description
Configuration for sandbox resource limits and behavior. The complete set of configuration needed to create a Sandbox
Implementations
Sourceimpl SandboxConfiguration
impl SandboxConfiguration
Sourcepub const DEFAULT_INPUT_SIZE: usize = 0x4000
pub const DEFAULT_INPUT_SIZE: usize = 0x4000
The default size of input data
Sourcepub const MIN_INPUT_SIZE: usize = 0x2000
pub const MIN_INPUT_SIZE: usize = 0x2000
The minimum size of input data
Sourcepub const DEFAULT_OUTPUT_SIZE: usize = 0x4000
pub const DEFAULT_OUTPUT_SIZE: usize = 0x4000
The default size of output data
Sourcepub const MIN_OUTPUT_SIZE: usize = 0x2000
pub const MIN_OUTPUT_SIZE: usize = 0x2000
The minimum size of output data
Sourcepub const DEFAULT_HOST_FUNCTION_DEFINITION_SIZE: usize = 0x1000
pub const DEFAULT_HOST_FUNCTION_DEFINITION_SIZE: usize = 0x1000
The default size of host function definitionsSET Host function definitions has its own page in memory, in order to be READ-ONLY from a guest’s perspective.
Sourcepub const MIN_HOST_FUNCTION_DEFINITION_SIZE: usize = 0x1000
pub const MIN_HOST_FUNCTION_DEFINITION_SIZE: usize = 0x1000
The minimum size of host function definitions
Sourcepub const DEFAULT_INTERRUPT_RETRY_DELAY: Duration
pub const DEFAULT_INTERRUPT_RETRY_DELAY: Duration
The default interrupt retry delay
Sourcepub const INTERRUPT_VCPU_SIGRTMIN_OFFSET: u8 = 0
pub const INTERRUPT_VCPU_SIGRTMIN_OFFSET: u8 = 0
The default signal offset from SIGRTMIN used to determine the signal number for interrupting
Sourcepub fn set_host_function_definition_size(
&mut self,
host_function_definition_size: usize,
)
pub fn set_host_function_definition_size( &mut self, host_function_definition_size: usize, )
Set the size of the memory buffer that is made available for serialising host function definitions the minimum value is MIN_HOST_FUNCTION_DEFINITION_SIZE
Sourcepub fn set_input_data_size(&mut self, input_data_size: usize)
pub fn set_input_data_size(&mut self, input_data_size: usize)
Set the size of the memory buffer that is made available for input to the guest the minimum value is MIN_INPUT_SIZE
Sourcepub fn set_output_data_size(&mut self, output_data_size: usize)
pub fn set_output_data_size(&mut self, output_data_size: usize)
Set the size of the memory buffer that is made available for output from the guest the minimum value is MIN_OUTPUT_SIZE
Sourcepub fn set_stack_size(&mut self, stack_size: u64)
pub fn set_stack_size(&mut self, stack_size: u64)
Set the stack size to use in the guest sandbox. If set to 0, the stack size will be determined from the PE file header
Sourcepub fn set_heap_size(&mut self, heap_size: u64)
pub fn set_heap_size(&mut self, heap_size: u64)
Set the heap size to use in the guest sandbox. If set to 0, the heap size will be determined from the PE file header
Sourcepub fn set_interrupt_retry_delay(&mut self, delay: Duration)
pub fn set_interrupt_retry_delay(&mut self, delay: Duration)
Sets the interrupt retry delay
Sourcepub fn get_interrupt_retry_delay(&self) -> Duration
pub fn get_interrupt_retry_delay(&self) -> Duration
Get the delay between retries for interrupts
Sourcepub fn get_interrupt_vcpu_sigrtmin_offset(&self) -> u8
pub fn get_interrupt_vcpu_sigrtmin_offset(&self) -> u8
Get the signal offset from SIGRTMIN used to determine the signal number for interrupting the VCPU thread
Sourcepub fn set_interrupt_vcpu_sigrtmin_offset(
&mut self,
offset: u8,
) -> Result<(), HyperlightError>
pub fn set_interrupt_vcpu_sigrtmin_offset( &mut self, offset: u8, ) -> Result<(), HyperlightError>
Sets the offset from SIGRTMIN to determine the real-time signal used for
interrupting the VCPU thread.
The final signal number is computed as SIGRTMIN + offset, and it must fall within
the valid range of real-time signals supported by the host system.
Returns Ok(()) if the offset is valid, or an error if it exceeds the maximum real-time signal number.