Script

Struct Script 

pub struct Script { /* private fields */ }
Types for working with JS script. Represents a JavaScript immutable handler script with metadata about its source location. The source location metadata is required to resolve relative locations when the script imports other modules using relative paths.

Implementations

Source

impl Script

pub fn from_content(content: impl Into<String>) -> Self

Create a script from a string with no base path for module resolution

pub fn from_file(path: impl AsRef<Path>) -> Result<Self>

Create a script by reading from a file

The base path is automatically set to the directory containing the file

pub fn with_virtual_base(self, path: impl AsRef<str>) -> Self

Set a virtual base path for module resolution.

pub fn content(&self) -> &str

Get the script content

pub fn base_path(&self) -> Option<&Path>

Get the base path for module resolution, if any