Snapshot

Struct Snapshot 

pub struct Snapshot { /* private fields */ }
A snapshot of sandbox state that can be used to restore it later. A wrapper around a SharedMemory reference and a snapshot of the memory therein