pub struct FileSystemEmbedded { /* private fields */ }Expand description
Module resolution and loading functionality. File system implementation that uses embedded modules compiled into the binary.
This implementation stores all module contents in a compile-time perfect hash map, eliminating any runtime file system access. This is the basic secure option for module loading as it provides a completely closed set of available modules without filesystem access.
Example
use hyperlight_js::embed_modules;
let fs = embed_modules! {
"math.js" => "../tests/fixtures/math.js",
"strings.js" => "../tests/fixtures/strings.js",
};
Implementations